@@ -1,11 +1,11 @@
-import babel from 'rollup-plugin-babel';
-import nodeResolve from 'rollup-plugin-node-resolve';
+import babel from '@rollup/plugin-babel';
+import nodeResolve from '@rollup/plugin-node-resolve';
 import { terser } from 'rollup-plugin-terser';
 import pkg from './package.json';
 
 const getBabelOptions = ({ useESModules }) => ({
   exclude: /node_modules/,
-  runtimeHelpers: true,
+  babelHelpers: 'runtime',
   plugins: [
     ['@babel/transform-runtime', { useESModules }]
   ]
