@@ -2,11 +2,11 @@ export default {
   name: 'navigator',
 
   lookup(options) {
-    let found = [];
+    const found = [];
 
     if (typeof navigator !== 'undefined') {
       if (navigator.languages) { // chrome only; not an array, so can't use .push.apply instead of iterating
-        for (let i=0; i < navigator.languages.length; i++) {
+        for (let i = 0; i < navigator.languages.length; i++) {
           found.push(navigator.languages[i]);
         }
       }
